==> org.codelibs.nekohtml.source_2.1.3.v20240413-0800.jar: org/codelibs/nekohtml/HTMLEventInfo.java <==
/*
 * Copyright 2002-2009 Andy Clark, Marc Guillemot
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codelibs.nekohtml;

/**
 * This interface is used to pass augmentated information to the
 * application through the XNI pipeline.
 *
 * @author Andy Clark
 *
 * @version $Id: HTMLEventInfo.java,v 1.4 2005/02/14 03:56:54 andyc Exp $
 */
public interface HTMLEventInfo {

    //
    // HTMLEventInfo methods
    //

    // location information

    /** Returns the line number of the beginning of this event.*/
    int getBeginLineNumber();

    /** Returns the column number of the beginning of this event.*/
    int getBeginColumnNumber();

    /** Returns the character offset of the beginning of this event.*/
    int getBeginCharacterOffset();

    /** Returns the line number of the end of this event.*/
    int getEndLineNumber();

    /** Returns the column number of the end of this event.*/
    int getEndColumnNumber();

    /** Returns the character offset of the end of this event.*/
    int getEndCharacterOffset();

    // other information

    /** Returns true if this corresponding event was synthesized. */
    boolean isSynthesized();

    /**
     * Synthesized infoset item.
     *
     * @author Andy Clark
     */
    class SynthesizedItem implements HTMLEventInfo {

        //
        // HTMLEventInfo methods
        //

        // location information

        /** Returns the line number of the beginning of this event.*/
        @Override
        public int getBeginLineNumber() {
            return -1;
        } // getBeginLineNumber():int

        /** Returns the column number of the beginning of this event.*/
        @Override
        public int getBeginColumnNumber() {
            return -1;
        } // getBeginColumnNumber():int

        /** Returns the character offset of the beginning of this event.*/
        @Override
        public int getBeginCharacterOffset() {
            return -1;
        } // getBeginCharacterOffset():int

        /** Returns the line number of the end of this event.*/
        @Override
        public int getEndLineNumber() {
            return -1;
        } // getEndLineNumber():int

        /** Returns the column number of the end of this event.*/
        @Override
        public int getEndColumnNumber() {
            return -1;
        } // getEndColumnNumber():int

        /** Returns the character offset of the end of this event.*/
        @Override
        public int getEndCharacterOffset() {
            return -1;
        } // getEndCharacterOffset():int

        // other information

        /** Returns true if this corresponding event was synthesized. */
        @Override
        public boolean isSynthesized() {
            return true;
        } // isSynthesized():boolean

        //
        // Object methods
        //

        /** Returns a string representation of this object. */
        @Override
        public String toString() {
            return "synthesized";
        } // toString():String

    } // class SynthesizedItem

} // interface HTMLEventInfo

==> org.codelibs.nekohtml.source_3.0.2.v20251220-1000.jar: org/codelibs/nekohtml/HTMLEventInfo.java <==
/*
 * Copyright 2012-2025 CodeLibs Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.codelibs.nekohtml;

/**
 * This interface is used to pass augmentated information to the
 * application through the XNI pipeline.
 *
 * @author Andy Clark
 *
 * @version $Id: HTMLEventInfo.java,v 1.4 2005/02/14 03:56:54 andyc Exp $
 */
public interface HTMLEventInfo {

    //
    // HTMLEventInfo methods
    //

    // location information

    /**
     * Returns the line number of the beginning of this event.
     * @return The line number where this event begins
     */
    int getBeginLineNumber();

    /**
     * Returns the column number of the beginning of this event.
     * @return The column number where this event begins
     */
    int getBeginColumnNumber();

    /**
     * Returns the character offset of the beginning of this event.
     * @return The character offset where this event begins
     */
    int getBeginCharacterOffset();

    /**
     * Returns the line number of the end of this event.
     * @return The line number where this event ends
     */
    int getEndLineNumber();

    /**
     * Returns the column number of the end of this event.
     * @return The column number where this event ends
     */
    int getEndColumnNumber();

    /**
     * Returns the character offset of the end of this event.
     * @return The character offset where this event ends
     */
    int getEndCharacterOffset();

    // other information

    /**
     * Returns true if this corresponding event was synthesized.
     * @return true if the event was synthesized, false otherwise
     */
    boolean isSynthesized();

    /**
     * Synthesized infoset item.
     *
     * @author Andy Clark
     */
    class SynthesizedItem implements HTMLEventInfo {

        /**
         * Default constructor. Creates a synthesized event info item.
         */
        public SynthesizedItem() {
            // Default constructor
        }

        //
        // HTMLEventInfo methods
        //

        // location information

        /** Returns the line number of the beginning of this event.*/
        @Override
        public int getBeginLineNumber() {
            return -1;
        } // getBeginLineNumber():int

        /** Returns the column number of the beginning of this event.*/
        @Override
        public int getBeginColumnNumber() {
            return -1;
        } // getBeginColumnNumber():int

        /** Returns the character offset of the beginning of this event.*/
        @Override
        public int getBeginCharacterOffset() {
            return -1;
        } // getBeginCharacterOffset():int

        /** Returns the line number of the end of this event.*/
        @Override
        public int getEndLineNumber() {
            return -1;
        } // getEndLineNumber():int

        /** Returns the column number of the end of this event.*/
        @Override
        public int getEndColumnNumber() {
            return -1;
        } // getEndColumnNumber():int

        /** Returns the character offset of the end of this event.*/
        @Override
        public int getEndCharacterOffset() {
            return -1;
        } // getEndCharacterOffset():int

        // other information

        /** Returns true if this corresponding event was synthesized. */
        @Override
        public boolean isSynthesized() {
            return true;
        } // isSynthesized():boolean

        //
        // Object methods
        //

        /** Returns a string representation of this object. */
        @Override
        public String toString() {
            return "synthesized";
        } // toString():String

    } // class SynthesizedItem

} // interface HTMLEventInfo
